@@ -1,3 +1,4 @@
+import json
 import os
 import random
 import shutil
@@ -25,6 +26,10 @@ def random_string(length):
     )
 
 
+def list_if(services):
+    return json.dumps([service[0] for service in services if service[1]])
+
+
 def common_domain(d1, d2):
     """
     Return the common domain between two domain names.
